# py-hv-networks (aka 'hv-networks')

Easy-ish Python interfaces to Heavy Vehicle network protocols on socketCAN, RP1210 adapters and **TruckDucks**

### Features

  * **J1708/J1587/J2497 Support**: Includes drivers and tools to dump (`j1708dump`) and send (`j1708send`) J1708/J1587/J2497 messages.
  * **J1939 Support**
  * **RP1210 Integration**
  * **TruckDuck Hardware**: Specifically designed to interface with the TruckDuck BeagleBone cape.
  * **CLI Utilities**: Ready-to-use command line scripts for quick diagnostics

### Installation

```bash
python -m pip install hv-networks
```
